@@ -4,6 +4,7 @@ import dash
 import flask
 import plotly
 import pkgutil
+import requests
 import mimetypes
 import dash_renderer
 import dash_core_components as dcc
@@ -37,6 +38,19 @@ class OAPDash(dash.Dash):
         self._add_url("opsramp-analytics-utils/<string:file_name>", self.serve_resource)
         self._add_url("asset-manifest.json", self.serve_manifest)
 
+    def index(self, *args, **kwargs):  # pylint: disable=unused-argument
+        index = super(OAPDash, self).index(args, kwargs)
+
+        # check auth
+        url = 'https://asura.opsramp.net/msps.json?_ajax=true'
+        res = requests.get(url, verify=False, cookies=flask.request.cookies)
+        if res.status_code !=200 or 'login_password' in res.text:
+            # TODO: get redirect url from flask.request.url
+            redirect_url = '/metered-usage-insight'
+            return flask.redirect(f"https://localhost/tenancy/web/login?cb={redirect_url}", code=302)
+
+        return index
+
     def serve_manifest(self):
         return {
             "files": {
@@ -74,7 +88,7 @@ class OAPDash(dash.Dash):
 
         # oap css files
         for file_path in self.static_files['css']:
-            body += pkgutil.get_data('oap_dash', 'assets/'+file_path).decode("utf-8")
+            body += pkgutil.get_data('analytics_sdk', 'assets/'+file_path).decode("utf-8")
 
         # custom css files
         for resource in self.css.get_all_css():
@@ -97,7 +111,7 @@ class OAPDash(dash.Dash):
 
         # oap js files
         for file_path in self.static_files['js']:
-            body += pkgutil.get_data('oap_dash', 'assets/'+file_path).decode("utf-8")
+            body += pkgutil.get_data('analytics_sdk', 'assets/'+file_path).decode("utf-8")
 
         # system js files
         mode = "dev" if self._dev_tools["props_check"] is True else "prod"
